@@ -1,4 +1,5 @@
 import os
+from dotenv import load_dotenv
 from pathlib import Path
 import pandas as pd
 import numpy as np
@@ -6,14 +7,27 @@ import time
 import subprocess
 
 from SharedData.Logger import Logger
-from SharedData.AWS import S3SyncDownloadMetadata
+from SharedData.SharedDataAWS import S3SyncDownloadMetadata
 
 class Metadata():
     
-    def __init__(self, name, s3read=False, s3write=False):
+    def __init__(self, name, mode='rw'):
+        if Logger.log is None:
+            load_dotenv()  # take environment variables from .env.
+            Logger(os.environ('PYTHONPATH')+'\Metadata.py')
+                
+        if mode == 'local':
+            self.s3read = False
+            self.s3write = False
+        elif mode == 'r':
+            self.s3read = True
+            self.s3write = False
+        elif mode == 'rw':
+            self.s3read = True
+            self.s3write = True
+        
+
         self.name = name
-        self.s3read = s3read
-        self.s3write = s3write
         self.xls = {}
         self.static = pd.DataFrame([])        
         self.symbols = pd.DataFrame([],dtype=str)
@@ -57,7 +71,6 @@ class Metadata():
                 self.symbols = self.symbols.set_index(self.symbols.columns[0])
             Logger.log.debug('%.2f done!' % (time.time()-tini))
 
-
     def save(self,save_excel=False):
         tini = time.time()
         Logger.log.debug('Saving symbols collection ' + self.name + ' ...')  
@@ -74,7 +87,8 @@ class Metadata():
             if not self.symbols.empty:
                 self.symbols.to_excel(writer,sheet_name='symbols')
             writer.save()        
-        self.debug('%.2f done!' % (time.time()-tini))
+        Logger.log.debug('Saving symbols collection ' + self.name + \
+            '%.2f done!' % (time.time()-tini))
     
     def mergeUpdate(self,newdf):
         ddidx = newdf.index.duplicated()
