@@ -1,13 +1,28 @@
+import os
+from dotenv import load_dotenv
 
 from SharedData.SharedDataFeeder import SharedDataFeeder
 from SharedData.Metadata import Metadata
+from SharedData.Logger import Logger
 
 class SharedData:
 
-    def __init__(self, database,s3read=False,s3write=False):                            
+    def __init__(self, database, mode='rw'):
+        if Logger.log is None:
+            load_dotenv()  # take environment variables from .env.
+            Logger(os.environ('PYTHONPATH')+'\SharedData.py')
+
         self.database = database
-        self.s3read = s3read
-        self.s3write = s3write
+
+        if mode == 'local':
+            self.s3read = False
+            self.s3write = False
+        elif mode == 'r':
+            self.s3read = True
+            self.s3write = False
+        elif mode == 'rw':
+            self.s3read = True
+            self.s3write = True
         
         # DATA DICTIONARY
         # SharedDataTimeSeries: data[feeder][period][tag] (date x symbols)
@@ -18,8 +33,7 @@ class SharedData:
         self.metadata = {}
         
         # DATASET
-        md = Metadata('DATASET/DATASET_' + database,\
-            s3read=self.s3read,s3write=self.s3write)
+        md = Metadata('DATASET/DATASET_' + database)
         self.dataset = md.static
 
     def __setitem__(self, feeder, value):
@@ -32,8 +46,7 @@ class SharedData:
 
     def getMetadata(self, collection):
         if not collection in self.metadata.keys():              
-            self.metadata[collection] = Metadata(collection,\
-                s3read=self.s3read,s3write=self.s3write)
+            self.metadata[collection] = Metadata(collection)
         return self.metadata[collection]
 
     def getSymbols(self, collection):        
